/***************************************************************************//**
* \file CapSense_RegisterMap.h
* \version 6.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSense v6.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2018), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSense_REGISTER_MAP_H)
#define CY_SENSE_CapSense_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSense_Configuration.h"
#include "CapSense_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSense_CONFIG_ID_VALUE                            (CapSense_dsRam.configId)
#define CapSense_CONFIG_ID_OFFSET                           (0u)
#define CapSense_CONFIG_ID_SIZE                             (2u)
#define CapSense_CONFIG_ID_PARAM_ID                         (0x87000000u)

#define CapSense_DEVICE_ID_VALUE                            (CapSense_dsRam.deviceId)
#define CapSense_DEVICE_ID_OFFSET                           (2u)
#define CapSense_DEVICE_ID_SIZE                             (2u)
#define CapSense_DEVICE_ID_PARAM_ID                         (0x8B000002u)

#define CapSense_HW_CLOCK_VALUE                             (CapSense_dsRam.hwClock)
#define CapSense_HW_CLOCK_OFFSET                            (4u)
#define CapSense_HW_CLOCK_SIZE                              (2u)
#define CapSense_HW_CLOCK_PARAM_ID                          (0x86000004u)

#define CapSense_TUNER_CMD_VALUE                            (CapSense_dsRam.tunerCmd)
#define CapSense_TUNER_CMD_OFFSET                           (6u)
#define CapSense_TUNER_CMD_SIZE                             (2u)
#define CapSense_TUNER_CMD_PARAM_ID                         (0xA1000006u)

#define CapSense_SCAN_COUNTER_VALUE                         (CapSense_dsRam.scanCounter)
#define CapSense_SCAN_COUNTER_OFFSET                        (8u)
#define CapSense_SCAN_COUNTER_SIZE                          (2u)
#define CapSense_SCAN_COUNTER_PARAM_ID                      (0x85000008u)

#define CapSense_STATUS_VALUE                               (CapSense_dsRam.status)
#define CapSense_STATUS_OFFSET                              (12u)
#define CapSense_STATUS_SIZE                                (4u)
#define CapSense_STATUS_PARAM_ID                            (0xCB00000Cu)

#define CapSense_WDGT_ENABLE0_VALUE                         (CapSense_dsRam.wdgtEnable[0u])
#define CapSense_WDGT_ENABLE0_OFFSET                        (16u)
#define CapSense_WDGT_ENABLE0_SIZE                          (4u)
#define CapSense_WDGT_ENABLE0_PARAM_ID                      (0xE6000010u)

#define CapSense_WDGT_STATUS0_VALUE                         (CapSense_dsRam.wdgtStatus[0u])
#define CapSense_WDGT_STATUS0_OFFSET                        (20u)
#define CapSense_WDGT_STATUS0_SIZE                          (4u)
#define CapSense_WDGT_STATUS0_PARAM_ID                      (0xCC000014u)

#define CapSense_SNS_STATUS0_VALUE                          (CapSense_dsRam.snsStatus[0u])
#define CapSense_SNS_STATUS0_OFFSET                         (24u)
#define CapSense_SNS_STATUS0_SIZE                           (1u)
#define CapSense_SNS_STATUS0_PARAM_ID                       (0x48000018u)

#define CapSense_SNS_STATUS1_VALUE                          (CapSense_dsRam.snsStatus[1u])
#define CapSense_SNS_STATUS1_OFFSET                         (25u)
#define CapSense_SNS_STATUS1_SIZE                           (1u)
#define CapSense_SNS_STATUS1_PARAM_ID                       (0x4E000019u)

#define CapSense_CSD0_CONFIG_VALUE                          (CapSense_dsRam.csd0Config)
#define CapSense_CSD0_CONFIG_OFFSET                         (26u)
#define CapSense_CSD0_CONFIG_SIZE                           (2u)
#define CapSense_CSD0_CONFIG_PARAM_ID                       (0xAA80001Au)

#define CapSense_MOD_CSD_CLK_VALUE                          (CapSense_dsRam.modCsdClk)
#define CapSense_MOD_CSD_CLK_OFFSET                         (28u)
#define CapSense_MOD_CSD_CLK_SIZE                           (1u)
#define CapSense_MOD_CSD_CLK_PARAM_ID                       (0x6F80001Cu)

#define CapSense_GUARD_RESOLUTION_VALUE                     (CapSense_dsRam.wdgtList.guard.resolution)
#define CapSense_GUARD_RESOLUTION_OFFSET                    (30u)
#define CapSense_GUARD_RESOLUTION_SIZE                      (2u)
#define CapSense_GUARD_RESOLUTION_PARAM_ID                  (0x8080001Eu)

#define CapSense_GUARD_FINGER_TH_VALUE                      (CapSense_dsRam.wdgtList.guard.fingerTh)
#define CapSense_GUARD_FINGER_TH_OFFSET                     (32u)
#define CapSense_GUARD_FINGER_TH_SIZE                       (2u)
#define CapSense_GUARD_FINGER_TH_PARAM_ID                   (0x80800020u)

#define CapSense_GUARD_NOISE_TH_VALUE                       (CapSense_dsRam.wdgtList.guard.noiseTh)
#define CapSense_GUARD_NOISE_TH_OFFSET                      (34u)
#define CapSense_GUARD_NOISE_TH_SIZE                        (1u)
#define CapSense_GUARD_NOISE_TH_PARAM_ID                    (0x44800022u)

#define CapSense_GUARD_NNOISE_TH_VALUE                      (CapSense_dsRam.wdgtList.guard.nNoiseTh)
#define CapSense_GUARD_NNOISE_TH_OFFSET                     (35u)
#define CapSense_GUARD_NNOISE_TH_SIZE                       (1u)
#define CapSense_GUARD_NNOISE_TH_PARAM_ID                   (0x42800023u)

#define CapSense_GUARD_HYSTERESIS_VALUE                     (CapSense_dsRam.wdgtList.guard.hysteresis)
#define CapSense_GUARD_HYSTERESIS_OFFSET                    (36u)
#define CapSense_GUARD_HYSTERESIS_SIZE                      (1u)
#define CapSense_GUARD_HYSTERESIS_PARAM_ID                  (0x49800024u)

#define CapSense_GUARD_ON_DEBOUNCE_VALUE                    (CapSense_dsRam.wdgtList.guard.onDebounce)
#define CapSense_GUARD_ON_DEBOUNCE_OFFSET                   (37u)
#define CapSense_GUARD_ON_DEBOUNCE_SIZE                     (1u)
#define CapSense_GUARD_ON_DEBOUNCE_PARAM_ID                 (0x4F800025u)

#define CapSense_GUARD_LOW_BSLN_RST_VALUE                   (CapSense_dsRam.wdgtList.guard.lowBslnRst)
#define CapSense_GUARD_LOW_BSLN_RST_OFFSET                  (38u)
#define CapSense_GUARD_LOW_BSLN_RST_SIZE                    (1u)
#define CapSense_GUARD_LOW_BSLN_RST_PARAM_ID                (0x45800026u)

#define CapSense_GUARD_IDAC_MOD0_VALUE                      (CapSense_dsRam.wdgtList.guard.idacMod[0u])
#define CapSense_GUARD_IDAC_MOD0_OFFSET                     (39u)
#define CapSense_GUARD_IDAC_MOD0_SIZE                       (1u)
#define CapSense_GUARD_IDAC_MOD0_PARAM_ID                   (0x4E000027u)

#define CapSense_GUARD_SNS_CLK_VALUE                        (CapSense_dsRam.wdgtList.guard.snsClk)
#define CapSense_GUARD_SNS_CLK_OFFSET                       (40u)
#define CapSense_GUARD_SNS_CLK_SIZE                         (2u)
#define CapSense_GUARD_SNS_CLK_PARAM_ID                     (0x82800028u)

#define CapSense_GUARD_SNS_CLK_SOURCE_VALUE                 (CapSense_dsRam.wdgtList.guard.snsClkSource)
#define CapSense_GUARD_SNS_CLK_SOURCE_OFFSET                (42u)
#define CapSense_GUARD_SNS_CLK_SOURCE_SIZE                  (1u)
#define CapSense_GUARD_SNS_CLK_SOURCE_PARAM_ID              (0x4680002Au)

#define CapSense_GUARD_FINGER_CAP_VALUE                     (CapSense_dsRam.wdgtList.guard.fingerCap)
#define CapSense_GUARD_FINGER_CAP_OFFSET                    (44u)
#define CapSense_GUARD_FINGER_CAP_SIZE                      (2u)
#define CapSense_GUARD_FINGER_CAP_PARAM_ID                  (0xA500002Cu)

#define CapSense_GUARD_SIGPFC_VALUE                         (CapSense_dsRam.wdgtList.guard.sigPFC)
#define CapSense_GUARD_SIGPFC_OFFSET                        (46u)
#define CapSense_GUARD_SIGPFC_SIZE                          (2u)
#define CapSense_GUARD_SIGPFC_PARAM_ID                      (0xA900002Eu)

#define CapSense_BUTTON_RESOLUTION_VALUE                    (CapSense_dsRam.wdgtList.button.resolution)
#define CapSense_BUTTON_RESOLUTION_OFFSET                   (48u)
#define CapSense_BUTTON_RESOLUTION_SIZE                     (2u)
#define CapSense_BUTTON_RESOLUTION_PARAM_ID                 (0x86810030u)

#define CapSense_BUTTON_FINGER_TH_VALUE                     (CapSense_dsRam.wdgtList.button.fingerTh)
#define CapSense_BUTTON_FINGER_TH_OFFSET                    (50u)
#define CapSense_BUTTON_FINGER_TH_SIZE                      (2u)
#define CapSense_BUTTON_FINGER_TH_PARAM_ID                  (0x8A810032u)

#define CapSense_BUTTON_NOISE_TH_VALUE                      (CapSense_dsRam.wdgtList.button.noiseTh)
#define CapSense_BUTTON_NOISE_TH_OFFSET                     (52u)
#define CapSense_BUTTON_NOISE_TH_SIZE                       (1u)
#define CapSense_BUTTON_NOISE_TH_PARAM_ID                   (0x4F810034u)

#define CapSense_BUTTON_NNOISE_TH_VALUE                     (CapSense_dsRam.wdgtList.button.nNoiseTh)
#define CapSense_BUTTON_NNOISE_TH_OFFSET                    (53u)
#define CapSense_BUTTON_NNOISE_TH_SIZE                      (1u)
#define CapSense_BUTTON_NNOISE_TH_PARAM_ID                  (0x49810035u)

#define CapSense_BUTTON_HYSTERESIS_VALUE                    (CapSense_dsRam.wdgtList.button.hysteresis)
#define CapSense_BUTTON_HYSTERESIS_OFFSET                   (54u)
#define CapSense_BUTTON_HYSTERESIS_SIZE                     (1u)
#define CapSense_BUTTON_HYSTERESIS_PARAM_ID                 (0x43810036u)

#define CapSense_BUTTON_ON_DEBOUNCE_VALUE                   (CapSense_dsRam.wdgtList.button.onDebounce)
#define CapSense_BUTTON_ON_DEBOUNCE_OFFSET                  (55u)
#define CapSense_BUTTON_ON_DEBOUNCE_SIZE                    (1u)
#define CapSense_BUTTON_ON_DEBOUNCE_PARAM_ID                (0x45810037u)

#define CapSense_BUTTON_LOW_BSLN_RST_VALUE                  (CapSense_dsRam.wdgtList.button.lowBslnRst)
#define CapSense_BUTTON_LOW_BSLN_RST_OFFSET                 (56u)
#define CapSense_BUTTON_LOW_BSLN_RST_SIZE                   (1u)
#define CapSense_BUTTON_LOW_BSLN_RST_PARAM_ID               (0x4C810038u)

#define CapSense_BUTTON_IDAC_MOD0_VALUE                     (CapSense_dsRam.wdgtList.button.idacMod[0u])
#define CapSense_BUTTON_IDAC_MOD0_OFFSET                    (57u)
#define CapSense_BUTTON_IDAC_MOD0_SIZE                      (1u)
#define CapSense_BUTTON_IDAC_MOD0_PARAM_ID                  (0x47010039u)

#define CapSense_BUTTON_SNS_CLK_VALUE                       (CapSense_dsRam.wdgtList.button.snsClk)
#define CapSense_BUTTON_SNS_CLK_OFFSET                      (58u)
#define CapSense_BUTTON_SNS_CLK_SIZE                        (2u)
#define CapSense_BUTTON_SNS_CLK_PARAM_ID                    (0x8881003Au)

#define CapSense_BUTTON_SNS_CLK_SOURCE_VALUE                (CapSense_dsRam.wdgtList.button.snsClkSource)
#define CapSense_BUTTON_SNS_CLK_SOURCE_OFFSET               (60u)
#define CapSense_BUTTON_SNS_CLK_SOURCE_SIZE                 (1u)
#define CapSense_BUTTON_SNS_CLK_SOURCE_PARAM_ID             (0x4D81003Cu)

#define CapSense_BUTTON_FINGER_CAP_VALUE                    (CapSense_dsRam.wdgtList.button.fingerCap)
#define CapSense_BUTTON_FINGER_CAP_OFFSET                   (62u)
#define CapSense_BUTTON_FINGER_CAP_SIZE                     (2u)
#define CapSense_BUTTON_FINGER_CAP_PARAM_ID                 (0xAF01003Eu)

#define CapSense_BUTTON_SIGPFC_VALUE                        (CapSense_dsRam.wdgtList.button.sigPFC)
#define CapSense_BUTTON_SIGPFC_OFFSET                       (64u)
#define CapSense_BUTTON_SIGPFC_SIZE                         (2u)
#define CapSense_BUTTON_SIGPFC_PARAM_ID                     (0xA2010040u)

#define CapSense_GUARD_SNS0_RAW0_VALUE                      (CapSense_dsRam.snsList.guard[0u].raw[0u])
#define CapSense_GUARD_SNS0_RAW0_OFFSET                     (66u)
#define CapSense_GUARD_SNS0_RAW0_SIZE                       (2u)
#define CapSense_GUARD_SNS0_RAW0_PARAM_ID                   (0x86000042u)

#define CapSense_GUARD_SNS0_BSLN0_VALUE                     (CapSense_dsRam.snsList.guard[0u].bsln[0u])
#define CapSense_GUARD_SNS0_BSLN0_OFFSET                    (68u)
#define CapSense_GUARD_SNS0_BSLN0_SIZE                      (2u)
#define CapSense_GUARD_SNS0_BSLN0_PARAM_ID                  (0x8B000044u)

#define CapSense_GUARD_SNS0_BSLN_EXT0_VALUE                 (CapSense_dsRam.snsList.guard[0u].bslnExt[0u])
#define CapSense_GUARD_SNS0_BSLN_EXT0_OFFSET                (70u)
#define CapSense_GUARD_SNS0_BSLN_EXT0_SIZE                  (1u)
#define CapSense_GUARD_SNS0_BSLN_EXT0_PARAM_ID              (0x4F000046u)

#define CapSense_GUARD_SNS0_DIFF_VALUE                      (CapSense_dsRam.snsList.guard[0u].diff)
#define CapSense_GUARD_SNS0_DIFF_OFFSET                     (72u)
#define CapSense_GUARD_SNS0_DIFF_SIZE                       (2u)
#define CapSense_GUARD_SNS0_DIFF_PARAM_ID                   (0x88000048u)

#define CapSense_GUARD_SNS0_NEG_BSLN_RST_CNT0_VALUE         (CapSense_dsRam.snsList.guard[0u].negBslnRstCnt[0u])
#define CapSense_GUARD_SNS0_NEG_BSLN_RST_CNT0_OFFSET        (74u)
#define CapSense_GUARD_SNS0_NEG_BSLN_RST_CNT0_SIZE          (1u)
#define CapSense_GUARD_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID      (0x4C00004Au)

#define CapSense_GUARD_SNS0_IDAC_COMP0_VALUE                (CapSense_dsRam.snsList.guard[0u].idacComp[0u])
#define CapSense_GUARD_SNS0_IDAC_COMP0_OFFSET               (75u)
#define CapSense_GUARD_SNS0_IDAC_COMP0_SIZE                 (1u)
#define CapSense_GUARD_SNS0_IDAC_COMP0_PARAM_ID             (0x4A00004Bu)

#define CapSense_BUTTON_SNS0_RAW0_VALUE                     (CapSense_dsRam.snsList.button[0u].raw[0u])
#define CapSense_BUTTON_SNS0_RAW0_OFFSET                    (76u)
#define CapSense_BUTTON_SNS0_RAW0_SIZE                      (2u)
#define CapSense_BUTTON_SNS0_RAW0_PARAM_ID                  (0x8900004Cu)

#define CapSense_BUTTON_SNS0_BSLN0_VALUE                    (CapSense_dsRam.snsList.button[0u].bsln[0u])
#define CapSense_BUTTON_SNS0_BSLN0_OFFSET                   (78u)
#define CapSense_BUTTON_SNS0_BSLN0_SIZE                     (2u)
#define CapSense_BUTTON_SNS0_BSLN0_PARAM_ID                 (0x8500004Eu)

#define CapSense_BUTTON_SNS0_BSLN_EXT0_VALUE                (CapSense_dsRam.snsList.button[0u].bslnExt[0u])
#define CapSense_BUTTON_SNS0_BSLN_EXT0_OFFSET               (80u)
#define CapSense_BUTTON_SNS0_BSLN_EXT0_SIZE                 (1u)
#define CapSense_BUTTON_SNS0_BSLN_EXT0_PARAM_ID             (0x47000050u)

#define CapSense_BUTTON_SNS0_DIFF_VALUE                     (CapSense_dsRam.snsList.button[0u].diff)
#define CapSense_BUTTON_SNS0_DIFF_OFFSET                    (82u)
#define CapSense_BUTTON_SNS0_DIFF_SIZE                      (2u)
#define CapSense_BUTTON_SNS0_DIFF_PARAM_ID                  (0x83000052u)

#define CapSense_BUTTON_SNS0_NEG_BSLN_RST_CNT0_VALUE        (CapSense_dsRam.snsList.button[0u].negBslnRstCnt[0u])
#define CapSense_BUTTON_SNS0_NEG_BSLN_RST_CNT0_OFFSET       (84u)
#define CapSense_BUTTON_SNS0_NEG_BSLN_RST_CNT0_SIZE         (1u)
#define CapSense_BUTTON_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID     (0x46000054u)

#define CapSense_BUTTON_SNS0_IDAC_COMP0_VALUE               (CapSense_dsRam.snsList.button[0u].idacComp[0u])
#define CapSense_BUTTON_SNS0_IDAC_COMP0_OFFSET              (85u)
#define CapSense_BUTTON_SNS0_IDAC_COMP0_SIZE                (1u)
#define CapSense_BUTTON_SNS0_IDAC_COMP0_PARAM_ID            (0x40000055u)

#define CapSense_SNR_TEST_WIDGET_ID_VALUE                   (CapSense_dsRam.snrTestWidgetId)
#define CapSense_SNR_TEST_WIDGET_ID_OFFSET                  (86u)
#define CapSense_SNR_TEST_WIDGET_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_WIDGET_ID_PARAM_ID                (0x61000056u)

#define CapSense_SNR_TEST_SENSOR_ID_VALUE                   (CapSense_dsRam.snrTestSensorId)
#define CapSense_SNR_TEST_SENSOR_ID_OFFSET                  (87u)
#define CapSense_SNR_TEST_SENSOR_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_SENSOR_ID_PARAM_ID                (0x67000057u)

#define CapSense_SNR_TEST_SCAN_COUNTER_VALUE                (CapSense_dsRam.snrTestScanCounter)
#define CapSense_SNR_TEST_SCAN_COUNTER_OFFSET               (88u)
#define CapSense_SNR_TEST_SCAN_COUNTER_SIZE                 (2u)
#define CapSense_SNR_TEST_SCAN_COUNTER_PARAM_ID             (0x8D000058u)

#define CapSense_SNR_TEST_RAW_COUNT0_VALUE                  (CapSense_dsRam.snrTestRawCount[0u])
#define CapSense_SNR_TEST_RAW_COUNT0_OFFSET                 (90u)
#define CapSense_SNR_TEST_RAW_COUNT0_SIZE                   (2u)
#define CapSense_SNR_TEST_RAW_COUNT0_PARAM_ID               (0x8100005Au)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSense_GUARD_PTR2SNS_FLASH_VALUE                  (CapSense_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSense_GUARD_PTR2SNS_FLASH_OFFSET                 (0u)
#define CapSense_GUARD_PTR2SNS_FLASH_SIZE                   (4u)
#define CapSense_GUARD_PTR2SNS_FLASH_PARAM_ID               (0xD1000000u)

#define CapSense_GUARD_PTR2WD_RAM_VALUE                     (CapSense_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSense_GUARD_PTR2WD_RAM_OFFSET                    (4u)
#define CapSense_GUARD_PTR2WD_RAM_SIZE                      (4u)
#define CapSense_GUARD_PTR2WD_RAM_PARAM_ID                  (0xD0000004u)

#define CapSense_GUARD_PTR2SNS_RAM_VALUE                    (CapSense_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSense_GUARD_PTR2SNS_RAM_OFFSET                   (8u)
#define CapSense_GUARD_PTR2SNS_RAM_SIZE                     (4u)
#define CapSense_GUARD_PTR2SNS_RAM_PARAM_ID                 (0xD3000008u)

#define CapSense_GUARD_PTR2FLTR_HISTORY_VALUE               (CapSense_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSense_GUARD_PTR2FLTR_HISTORY_OFFSET              (12u)
#define CapSense_GUARD_PTR2FLTR_HISTORY_SIZE                (4u)
#define CapSense_GUARD_PTR2FLTR_HISTORY_PARAM_ID            (0xD200000Cu)

#define CapSense_GUARD_PTR2DEBOUNCE_VALUE                   (CapSense_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSense_GUARD_PTR2DEBOUNCE_OFFSET                  (16u)
#define CapSense_GUARD_PTR2DEBOUNCE_SIZE                    (4u)
#define CapSense_GUARD_PTR2DEBOUNCE_PARAM_ID                (0xD4000010u)

#define CapSense_GUARD_STATIC_CONFIG_VALUE                  (CapSense_dsFlash.wdgtArray[0].staticConfig)
#define CapSense_GUARD_STATIC_CONFIG_OFFSET                 (20u)
#define CapSense_GUARD_STATIC_CONFIG_SIZE                   (4u)
#define CapSense_GUARD_STATIC_CONFIG_PARAM_ID               (0xD5000014u)

#define CapSense_GUARD_TOTAL_NUM_SNS_VALUE                  (CapSense_dsFlash.wdgtArray[0].totalNumSns)
#define CapSense_GUARD_TOTAL_NUM_SNS_OFFSET                 (24u)
#define CapSense_GUARD_TOTAL_NUM_SNS_SIZE                   (2u)
#define CapSense_GUARD_TOTAL_NUM_SNS_PARAM_ID               (0x99000018u)

#define CapSense_GUARD_TYPE_VALUE                           (CapSense_dsFlash.wdgtArray[0].wdgtType)
#define CapSense_GUARD_TYPE_OFFSET                          (26u)
#define CapSense_GUARD_TYPE_SIZE                            (1u)
#define CapSense_GUARD_TYPE_PARAM_ID                        (0x5D00001Au)

#define CapSense_GUARD_NUM_COLS_VALUE                       (CapSense_dsFlash.wdgtArray[0].numCols)
#define CapSense_GUARD_NUM_COLS_OFFSET                      (27u)
#define CapSense_GUARD_NUM_COLS_SIZE                        (1u)
#define CapSense_GUARD_NUM_COLS_PARAM_ID                    (0x5B00001Bu)

#define CapSense_GUARD_PTR2NOISE_ENVLP_VALUE                (CapSense_dsFlash.wdgtArray[0].ptr2NoiseEnvlp)
#define CapSense_GUARD_PTR2NOISE_ENVLP_OFFSET               (28u)
#define CapSense_GUARD_PTR2NOISE_ENVLP_SIZE                 (4u)
#define CapSense_GUARD_PTR2NOISE_ENVLP_PARAM_ID             (0xD700001Cu)

#define CapSense_BUTTON_PTR2SNS_FLASH_VALUE                 (CapSense_dsFlash.wdgtArray[1].ptr2SnsFlash)
#define CapSense_BUTTON_PTR2SNS_FLASH_OFFSET                (32u)
#define CapSense_BUTTON_PTR2SNS_FLASH_SIZE                  (4u)
#define CapSense_BUTTON_PTR2SNS_FLASH_PARAM_ID              (0xD8010020u)

#define CapSense_BUTTON_PTR2WD_RAM_VALUE                    (CapSense_dsFlash.wdgtArray[1].ptr2WdgtRam)
#define CapSense_BUTTON_PTR2WD_RAM_OFFSET                   (36u)
#define CapSense_BUTTON_PTR2WD_RAM_SIZE                     (4u)
#define CapSense_BUTTON_PTR2WD_RAM_PARAM_ID                 (0xD9010024u)

#define CapSense_BUTTON_PTR2SNS_RAM_VALUE                   (CapSense_dsFlash.wdgtArray[1].ptr2SnsRam)
#define CapSense_BUTTON_PTR2SNS_RAM_OFFSET                  (40u)
#define CapSense_BUTTON_PTR2SNS_RAM_SIZE                    (4u)
#define CapSense_BUTTON_PTR2SNS_RAM_PARAM_ID                (0xDA010028u)

#define CapSense_BUTTON_PTR2FLTR_HISTORY_VALUE              (CapSense_dsFlash.wdgtArray[1].ptr2FltrHistory)
#define CapSense_BUTTON_PTR2FLTR_HISTORY_OFFSET             (44u)
#define CapSense_BUTTON_PTR2FLTR_HISTORY_SIZE               (4u)
#define CapSense_BUTTON_PTR2FLTR_HISTORY_PARAM_ID           (0xDB01002Cu)

#define CapSense_BUTTON_PTR2DEBOUNCE_VALUE                  (CapSense_dsFlash.wdgtArray[1].ptr2DebounceArr)
#define CapSense_BUTTON_PTR2DEBOUNCE_OFFSET                 (48u)
#define CapSense_BUTTON_PTR2DEBOUNCE_SIZE                   (4u)
#define CapSense_BUTTON_PTR2DEBOUNCE_PARAM_ID               (0xDD010030u)

#define CapSense_BUTTON_STATIC_CONFIG_VALUE                 (CapSense_dsFlash.wdgtArray[1].staticConfig)
#define CapSense_BUTTON_STATIC_CONFIG_OFFSET                (52u)
#define CapSense_BUTTON_STATIC_CONFIG_SIZE                  (4u)
#define CapSense_BUTTON_STATIC_CONFIG_PARAM_ID              (0xDC010034u)

#define CapSense_BUTTON_TOTAL_NUM_SNS_VALUE                 (CapSense_dsFlash.wdgtArray[1].totalNumSns)
#define CapSense_BUTTON_TOTAL_NUM_SNS_OFFSET                (56u)
#define CapSense_BUTTON_TOTAL_NUM_SNS_SIZE                  (2u)
#define CapSense_BUTTON_TOTAL_NUM_SNS_PARAM_ID              (0x90010038u)

#define CapSense_BUTTON_TYPE_VALUE                          (CapSense_dsFlash.wdgtArray[1].wdgtType)
#define CapSense_BUTTON_TYPE_OFFSET                         (58u)
#define CapSense_BUTTON_TYPE_SIZE                           (1u)
#define CapSense_BUTTON_TYPE_PARAM_ID                       (0x5401003Au)

#define CapSense_BUTTON_NUM_COLS_VALUE                      (CapSense_dsFlash.wdgtArray[1].numCols)
#define CapSense_BUTTON_NUM_COLS_OFFSET                     (59u)
#define CapSense_BUTTON_NUM_COLS_SIZE                       (1u)
#define CapSense_BUTTON_NUM_COLS_PARAM_ID                   (0x5201003Bu)

#define CapSense_BUTTON_PTR2NOISE_ENVLP_VALUE               (CapSense_dsFlash.wdgtArray[1].ptr2NoiseEnvlp)
#define CapSense_BUTTON_PTR2NOISE_ENVLP_OFFSET              (60u)
#define CapSense_BUTTON_PTR2NOISE_ENVLP_SIZE                (4u)
#define CapSense_BUTTON_PTR2NOISE_ENVLP_PARAM_ID            (0xDE01003Cu)


#endif /* End CY_SENSE_CapSense_REGISTER_MAP_H */


/* [] END OF FILE */
